Class: Altertable::Lakehouse::Models::AppendRequest
- Defined in:
- lib/altertable/lakehouse/models.rb
Instance Attribute Summary collapse
-
#payload ⇒ Object
readonly
Returns the value of attribute payload.
Instance Method Summary collapse
-
#initialize(payload) ⇒ AppendRequest
constructor
Payload can be a single Hash or an Array of Hashes.
- #to_h ⇒ Object
Constructor Details
#initialize(payload) ⇒ AppendRequest
Payload can be a single Hash or an Array of Hashes
14 15 16 |
# File 'lib/altertable/lakehouse/models.rb', line 14 def initialize(payload) @payload = payload end |
Instance Attribute Details
#payload ⇒ Object (readonly)
Returns the value of attribute payload.
11 12 13 |
# File 'lib/altertable/lakehouse/models.rb', line 11 def payload @payload end |
Instance Method Details
#to_h ⇒ Object
18 19 20 |
# File 'lib/altertable/lakehouse/models.rb', line 18 def to_h @payload end |